@@ -50,6 +50,7 @@ NSString *const VLCPasscodeValidated = @"VLCPasscodeValidated";
     BOOL _passcodeValidated;
     BOOL _isRunningMigration;
     BOOL _isComingFromHandoff;
+    BOOL _isComingFromURLHandler;
 }
 
 @end
@@ -340,6 +341,11 @@ continueUserActivity:(NSUserActivity *)userActivity
     } else if(_isComingFromHandoff) {
         _isComingFromHandoff = NO;
     }
+
+    if (_isComingFromURLHandler) {
+        _isComingFromURLHandler = NO;
+        [[VLCPlaybackController sharedInstance] startPlayback];
+    }
 }
 
 - (void)applicationWillTerminate:(UIApplication *)application
@@ -566,11 +572,12 @@ continueUserActivity:(NSUserActivity *)userActivity
     VLCPlaybackController *vpc = [VLCPlaybackController sharedInstance];
 
     vpc.url = url;
+
     vpc.successCallback = successCallback;
     vpc.errorCallback = errorCallback;
     vpc.fullscreenSessionRequested = YES;
 
-    [vpc startPlayback];
+    _isComingFromURLHandler = YES;
 }
 
 - (void)openMovieFromURL:(NSURL *)url
